<?php
/**
 * VW Interior Designs Theme Customizer
 *
 * @package VW Interior Designs
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function vw_interior_designs_custom_controls() {

    load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'vw_interior_designs_custom_controls' );

function vw_interior_designs_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . 'inc/customize-homepage/class-customize-homepage.php' );

	//add home page setting pannel
	$wp_customize->add_panel( 'vw_interior_designs_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'VW Settings', 'vw-interior-designs' ),
	    'description' => __( 'Description of what this panel does.', 'vw-interior-designs' ),
	) );

	$wp_customize->add_section( 'vw_interior_designs_left_right', array(
    	'title'      => __( 'General Settings', 'vw-interior-designs' ),
		'priority'   => 30,
		'panel' => 'vw_interior_designs_panel_id'
	) );

	$wp_customize->add_setting('vw_interior_designs_width_option',array(
        'default' => __('Full Width','vw-interior-designs'),
        'sanitize_callback' => 'vw_interior_designs_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Interior_Designs_Image_Radio_Control($wp_customize, 'vw_interior_designs_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','vw-interior-designs'),
        'description' => __('Here you can change the width layout of Website.','vw-interior-designs'),
        'section' => 'vw_interior_designs_left_right',
        'choices' => array(
            'Full Width' => get_template_directory_uri().'/images/full-width.png',
            'Wide Width' => get_template_directory_uri().'/images/wide-width.png',
            'Boxed' => get_template_directory_uri().'/images/boxed-width.png',
    ))));

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('vw_interior_designs_theme_options',array(
        'default' => __('Right Sidebar','vw-interior-designs'),
        'sanitize_callback' => 'vw_interior_designs_sanitize_choices'	        
	) );
	$wp_customize->add_control('vw_interior_designs_theme_options', array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','vw-interior-designs'),
        'description' => __('Here you can change the sidebar layout for posts. ','vw-interior-designs'),
        'section' => 'vw_interior_designs_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-interior-designs'),
            'Right Sidebar' => __('Right Sidebar','vw-interior-designs'),
            'One Column' => __('One Column','vw-interior-designs'),
            'Three Columns' => __('Three Columns','vw-interior-designs'),
            'Four Columns' => __('Four Columns','vw-interior-designs'),
            'Grid Layout' => __('Grid Layout','vw-interior-designs')
        ),
	));

	$wp_customize->add_setting('vw_interior_designs_page_layout',array(
        'default' => __('One Column','vw-interior-designs'),
        'sanitize_callback' => 'vw_interior_designs_sanitize_choices'
	));
	$wp_customize->add_control('vw_interior_designs_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','vw-interior-designs'),
        'description' => __('Here you can change the sidebar layout for pages. ','vw-interior-designs'),
        'section' => 'vw_interior_designs_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-interior-designs'),
            'Right Sidebar' => __('Right Sidebar','vw-interior-designs'),
            'One Column' => __('One Column','vw-interior-designs')
        ),
	) );
    
	//Slider
	$wp_customize->add_section( 'vw_interior_designs_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'vw-interior-designs' ),
		'priority'   => null,
		'panel' => 'vw_interior_designs_panel_id'
	) );

	$wp_customize->add_setting( 'vw_interior_designs_slider_hide_show',
       array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_interior_designs_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Interior_Designs_Toggle_Switch_Custom_Control( $wp_customize, 'vw_interior_designs_slider_hide_show',
       array(
          'label' => esc_html__( 'Show / Hide Slider','vw-interior-designs' ),
          'section' => 'vw_interior_designs_slidersettings'
    )));

	for ( $count = 1; $count <= 4; $count++ ) {

		// Add color scheme setting and control.
		$wp_customize->add_setting( 'vw_interior_designs_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'vw_interior_designs_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'vw_interior_designs_slider_page' . $count, array(
			'label'    => __( 'Select Slide Image Page', 'vw-interior-designs' ),
			'description' => __('Slider image size (1500 x 600)','vw-interior-designs'),
			'section'  => 'vw_interior_designs_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	//content layout
	$wp_customize->add_setting('vw_interior_designs_slider_content_option',array(
        'default' => __('Center','vw-interior-designs'),
        'sanitize_callback' => 'vw_interior_designs_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Interior_Designs_Image_Radio_Control($wp_customize, 'vw_interior_designs_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','vw-interior-designs'),
        'section' => 'vw_interior_designs_slidersettings',
        'choices' => array(
            'Left' => get_template_directory_uri().'/images/slider-content1.png',
            'Center' => get_template_directory_uri().'/images/slider-content2.png',
            'Right' => get_template_directory_uri().'/images/slider-content3.png',
    ))));

    //Slider excerpt
	$wp_customize->add_setting( 'vw_interior_designs_slider_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_interior_designs_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','vw-interior-designs' ),
		'section'     => 'vw_interior_designs_slidersettings',
		'type'        => 'range',
		'settings'    => 'vw_interior_designs_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 2,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Opacity
	$wp_customize->add_setting('vw_interior_designs_slider_opacity_color',array(
      'default'              => 0.5,
      'sanitize_callback' => 'vw_interior_designs_sanitize_choices'
	));

	$wp_customize->add_control( 'vw_interior_designs_slider_opacity_color', array(
	'label'       => esc_html__( 'Slider Image Opacity','vw-interior-designs' ),
	'section'     => 'vw_interior_designs_slidersettings',
	'type'        => 'select',
	'settings'    => 'vw_interior_designs_slider_opacity_color',
	'choices' => array(
      '0' =>  esc_attr('0','vw-interior-designs'),
      '0.1' =>  esc_attr('0.1','vw-interior-designs'),
      '0.2' =>  esc_attr('0.2','vw-interior-designs'),
      '0.3' =>  esc_attr('0.3','vw-interior-designs'),
      '0.4' =>  esc_attr('0.4','vw-interior-designs'),
      '0.5' =>  esc_attr('0.5','vw-interior-designs'),
      '0.6' =>  esc_attr('0.6','vw-interior-designs'),
      '0.7' =>  esc_attr('0.7','vw-interior-designs'),
      '0.8' =>  esc_attr('0.8','vw-interior-designs'),
      '0.9' =>  esc_attr('0.9','vw-interior-designs')
	),
	));

	$wp_customize->add_setting( 'vw_interior_designs_search_hide_show',
       array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_interior_designs_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Interior_Designs_Toggle_Switch_Custom_Control( $wp_customize, 'vw_interior_designs_search_hide_show',
       array(
          'label' => esc_html__( 'Show / Hide Search','vw-interior-designs' ),
          'section' => 'vw_interior_designs_slidersettings'
    )));

	//Video Post Section
	$wp_customize->add_section( 'vw_interior_designs_video_post_section' , array(
    	'title'      => __( 'Video Post Section', 'vw-interior-designs' ),
		'priority'   => null,
		'panel' => 'vw_interior_designs_panel_id'
	) );

	$args = array('numberposts' => -1);
	$post_list = get_posts($args);
	$i = 0;
	$pst[]= 'select';
	foreach($post_list as $post){
		$pst[$post->post_title] = $post->post_title;
	}

	$wp_customize->add_setting('vw_interior_designs_video_section',array(
		'sanitize_callback' => 'vw_interior_designs_sanitize_choices',
	));
	$wp_customize->add_control('vw_interior_designs_video_section',array(
		'type'    => 'select',
		'choices' => $pst,
		'label' => __('Select post','vw-interior-designs'),
		'section' => 'vw_interior_designs_video_post_section',
	));

	//Video post excerpt
	$wp_customize->add_setting( 'vw_interior_designs_videopost_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_interior_designs_videopost_excerpt_number', array(
		'label'       => esc_html__( 'Video Post Excerpt Length','vw-interior-designs' ),
		'section'     => 'vw_interior_designs_video_post_section',
		'type'        => 'range',
		'settings'    => 'vw_interior_designs_videopost_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Blog Post
	$wp_customize->add_section('vw_interior_designs_blog_post',array(
		'title'	=> __('Blog Post Settings','vw-interior-designs'),
		'panel' => 'vw_interior_designs_panel_id',
	));	

	$wp_customize->add_setting( 'vw_interior_designs_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_interior_designs_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Interior_Designs_Toggle_Switch_Custom_Control( $wp_customize, 'vw_interior_designs_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','vw-interior-designs' ),
        'section' => 'vw_interior_designs_blog_post'
    )));

    $wp_customize->add_setting( 'vw_interior_designs_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_interior_designs_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Interior_Designs_Toggle_Switch_Custom_Control( $wp_customize, 'vw_interior_designs_toggle_author',array(
		'label' => esc_html__( 'Author','vw-interior-designs' ),
		'section' => 'vw_interior_designs_blog_post'
    )));

    $wp_customize->add_setting( 'vw_interior_designs_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_interior_designs_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Interior_Designs_Toggle_Switch_Custom_Control( $wp_customize, 'vw_interior_designs_toggle_comments',array(
		'label' => esc_html__( 'Comments','vw-interior-designs' ),
		'section' => 'vw_interior_designs_blog_post'
    )));

    $wp_customize->add_setting( 'vw_interior_designs_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_interior_designs_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','vw-interior-designs' ),
		'section'     => 'vw_interior_designs_blog_post',
		'type'        => 'range',
		'settings'    => 'vw_interior_designs_excerpt_number',
		'input_attrs' => array(
			'step'             => 2,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Content Creation
	$wp_customize->add_section( 'vw_interior_designs_content_section' , array(
    	'title' => __( 'Customize Home Page', 'vw-interior-designs' ),
		'priority' => null,
		'panel' => 'vw_interior_designs_panel_id'
	) );

	$wp_customize->add_setting('vw_interior_designs_content_creation_main_control', array(
		'sanitize_callback' => 'esc_html',
	) );

	$homepage= get_option( 'page_on_front' );

	$wp_customize->add_control(	new VW_Interior_Designs_Content_Creation( $wp_customize, 'vw_interior_designs_content_creation_main_control', array(
		'options' => array(
			esc_html__( 'First select static page in homepage setting for front page.Below given edit button is to customize Home Page. Just click on the edit option, add whatever elements you want to include in the homepage, save the changes and you are good to go.','vw-interior-designs' ),
		),
		'section' => 'vw_interior_designs_content_section',
		'button_url'  => admin_url( 'post.php?post='.$homepage.'&action=edit'),
		'button_text' => esc_html__( 'Edit', 'vw-interior-designs' ),
	) ) );
	
	//Footer Text
	$wp_customize->add_section('vw_interior_designs_footer',array(
		'title'	=> __('Footer','vw-interior-designs'),
		'description'=> __('This section will appear in the footer','vw-interior-designs'),
		'panel' => 'vw_interior_designs_panel_id',
	));	
	
	$wp_customize->add_setting('vw_interior_designs_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_interior_designs_footer_text',array(
		'label'	=> __('Copyright Text','vw-interior-designs'),
		'section'=> 'vw_interior_designs_footer',
		'setting'=> 'vw_interior_designs_footer_text',
		'type'=> 'text'
	));	

	$wp_customize->add_setting( 'vw_interior_designs_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_interior_designs_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Interior_Designs_Toggle_Switch_Custom_Control( $wp_customize, 'vw_interior_designs_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','vw-interior-designs' ),
      	'section' => 'vw_interior_designs_footer'
    )));

	$wp_customize->add_setting('vw_interior_designs_scroll_top_alignment',array(
        'default' => __('Right','vw-interior-designs'),
        'sanitize_callback' => 'vw_interior_designs_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Interior_Designs_Image_Radio_Control($wp_customize, 'vw_interior_designs_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','vw-interior-designs'),
        'section' => 'vw_interior_designs_footer',
        'settings' => 'vw_interior_designs_scroll_top_alignment',
        'choices' => array(
            'Left' => get_template_directory_uri().'/images/layout1.png',
            'Center' => get_template_directory_uri().'/images/layout2.png',
            'Right' => get_template_directory_uri().'/images/layout3.png'
    ))));
}

add_action( 'customize_register', 'vw_interior_designs_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Interior_Designs_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Interior_Designs_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(new VW_Interior_Designs_Customize_Section_Pro($manager,'example_1',array(
			'priority'   => 1,
			'title'    => esc_html__( 'Interior Pro Theme', 'vw-interior-designs' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'vw-interior-designs' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/interior-design-wordpress-theme/'),
		)));

		$manager->add_section(new VW_Interior_Designs_Customize_Section_Pro($manager,'example_2',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'vw-interior-designs' ),
			'pro_text' => esc_html__( 'DOCS', 'vw-interior-designs' ),
			'pro_url'  => admin_url('themes.php?page=vw_interior_designs_guide'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-interior-designs-customize-controls', trailingslashit( get_template_directory_uri() ) . '/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-interior-designs-customize-controls', trailingslashit( get_template_directory_uri() ) . '/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
VW_Interior_Designs_Customize::get_instance();